@@ -510,10 +510,10 @@ static void prepare_pcap(void) {
 
 #else 
 
-    /* PCAP timeouts tend to be broken, so we'll use a minimum value
+    /* PCAP timeouts tend to be broken, so we'll use a very small value
        and rely on select() instead. */
 
-    pt = pcap_open_live((char*)use_iface, SNAPLEN, set_promisc, 1, pcap_err);
+    pt = pcap_open_live((char*)use_iface, SNAPLEN, set_promisc, 5, pcap_err);
 
 #endif /* ^__CYGWIN__ */
 
@@ -805,12 +805,15 @@ static void live_event_loop(void) {
     s32 pret, i;
     u32 cur;
 
-    /* We use a 250 ms timeout to keep Ctrl-C responsive without resortng to
-       silly sigaction hackery or unsafe signal handler code. */
+    /* We had a 250 ms timeout to keep Ctrl-C responsive without resortng
+       to silly sigaction hackery or unsafe signal handler code. Unfortunately,
+       if poll() timeout is much longer than pcap timeout, we end up with
+       dropped packets on VMs. Seems like a kernel bug, but for now, this
+       loop is a bit busier than it needs to be... */
 
 poll_again:
 
-    pret = poll(pfds, pfd_count, 250);
+    pret = poll(pfds, pfd_count, 10);
 
     if (pret < 0) {
       if (errno == EINTR) break;
